==> nextcloud-app-notes-3.6.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/notes/l10n/el.js <==
OC.L10N.register(
    "notes",
    {
    "Error" : "Σφάλμα",
    "New note" : "Νέα σημείωση",
    "Notes" : "Σημειώσεις",
    "Distraction-free notes and writing" : "Χωρίς περιορισμούς σημειώσεις και γραφή",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Η εφαρμογή \"Σημειώσεις\" είναι μια χωρίς περιττά εφαρμογή διαχείρισης σημειώσεων για το [Nextcloud](https://www.nextcloud.com/). Παρέχει κατηγορίες για καλύτερη οργάνωση και υποστηρίζει μορφοποίηση χρησιμοποιώντας τη σύνταξη [Markdown] (https://en.wikipedia.org/wiki/Markdown). Οι σημειώσεις αποθηκεύονται ως αρχεία στο Nextcloud, ώστε να μπορείτε να τα προβάλετε και να τα επεξεργαστείτε με κάθε λογισμικό Nextcloud. Επιπλέον, ένα ξεχωριστό [REST API](docs/api/README.md) επιτρέπει την εύκολη ενσωμάτωση σε εφαρμογές τρίτων (προς το παρόν, υπάρχουν εφαρμογές σημειώσεων για το  [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) και [console](https://git.danielmoch.com/nncli/about) που επιτρέπουν εύκολη πρόσβαση στις σημειώσεις σας στο Nextcloud). Άλλα χαρακτηριστικά περιλαμβάνουν την επισήμανση σημειώσεων ως αγαπημένων.",
    "Please see Nextcloud server log for details." : "Για λεπτομέρειες παρακαλούμε δείτε το ιστορικό του διακομιστή Nextcloud.",
    "Deleted {title}" : "Διεγραμμένες {title}",
    "Deleted {number} notes" : "Διαγράφηκαν {number} σημειώσεις",
    "Undo Delete" : "Αναίρεση διαγραφής",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Υπάρχουν σημειώσεις που δεν έχουν αποθηκευτεί. Φεύγοντας από την σελίδα θα διαγραφούν οι αλλαγές!",
    "Settings" : "Ρυθμίσεις",
    "Folder to store your notes" : "Φάκελος αποθήκευσης των σημειώσεών σας",
    "path to notes" : "διαδρομή στις σημειώσεις",
    "File extension for new notes" : "Πρόσθετο αρχείου για νέες σημειώσεις",
    "All notes" : "Όλες οι σημειώσεις",
    "Categories" : "Κατηγορίες",
    "No search result for “{search}” in {category}" : "Κανένα αποτέλεσμα αναζήτησης για “{search}” σε {category}",
    "No search result for “{search}”" : "Κανένα αποτέλεσμα αναζήτησης για “{search}”",
    "Loading …" : "Φόρτωση…",
    "Search result for “{search}” in {category}" : "Αποτέλεσμα αναζήτησης για “{search}” σε {category}",
    "Search result for “{search}”" : "Αποτέλεσμα αναζήτησης για “{search}”",
    "Today" : "Σήμερα",
    "Yesterday" : "Χθές",
    "This week" : "Αυτή την εβδομάδα",
    "Last week" : "Προηγούμενη εβδομάδα",
    "This month" : "Αυτό το μήνα",
    "Last month" : "Προηγούμενος μήνας",
    "Rename" : "Μετονομασία",
    "Note's title" : "Τίτλος σημειωματάριου",
    "Delete note" : "Διαγραφή σημείωσης",
    "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
    "Add to favorites" : "Προσθήκη στα αγαπημένα ",
    "Error during preparing note for deletion." : "Σφάλμα κατά την προετοιμασία της σημείωσης για διαγραφή.",
    "Empty note" : "Κενή σημείωση",
    "Write …" : "Σύνταξη ...",
    "Details" : "Λεπτομέρειες",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Επεξεργασία",
    "Preview" : "Προεπισκόπηση",
    "Exit full screen" : "Έξοδος πλήρους οθόνης",
    "Full screen" : "Πλήρης οθόνη",
    "Save failed. Click to retry." : "Η αποθήκευση απέτυχε. Κλίκ για προσπάθεια ξανά.",
    "Set category" : "Ορίστε κατηγορία",
    "Category" : "Κατηγορία",
    "Uncategorized" : "Χωρίς κατηγορία",
    "Click here to save manually" : "Κλίκ εδώ για χειροκίνητη αποθήκευση",
    "Saving failed!" : "Απέτυχε η αποθήκευση!",
    "Last modified: {date}" : "Τελευταία τροποίηση: {date}",
    "Note has unsaved changes" : "Η σημείωση έχει αλλαγές που δεν έχουν αποθηκευτεί",
    "Subcategory" : "Υποκατηγορία",
    "_%n word_::_%n words_" : ["%n λέξη","%n λέξεις"],
    "_%n character_::_%n characters_" : ["%n χαρακτήρας","%n χαρακτήρες"],
    "Write down your thoughts without any distractions." : "Κρατήστε τις σκέψεις σας χωρίς περιορισμούς.",
    "Use Markdown markups to style your text." : "Με χρήση του Markdown για να δώσετε στυλ στο κείμενό σας.",
    "Organize your notes in categories." : "Οργανώστε τις σημειώσεις σας σε κατηγορίες.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Εγκαταστήστε την εφαρμογή στο κινητό σας για πρόσβαση από οπουδήποτε.",
    "Android app" : "Εφαρμογή Android",
    "iOS app" : "Εφαρμογή iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Ξεκινήστε μια σημείωση κάνοντας κλικ στο \"{newnote}\" από το μενού εφαρμογών.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Μπορείτε να δημιουργήσετε υποκατηγορίες χρησιμοποιώντας το \"/\" ως οριοθέτη μεταξύ της κατηγορίας και της υποκατηγορίας, π.χ. \"{Parent}/{sub}\".",
    "Note not found." : "Δεν βρέθηκε η σημείωση.",
    "Note is locked." : "Η σημείωση είναι κλειδωμένη.",
    "Insufficient storage." : "Μη επαρκής αποθηκευτικός χώρος.",
    "See JavaScript console and server log for details." : "Δείτε την κονσόλα JavaScript και το ιστορικό του διακομιστή για λεπτομέρειες.",
    "Updating settings has failed." : "Η ενημέρωση ρυθμίσεων απέτυχε.",
    "Error from Nextcloud server: {msg}" : "Σφάλμα από τον διακομιστή Nextcloud: {msg}",
    "Fetching notes has failed." : "Η λήψη σημειώσεων απέτυχε.",
    "Fetching note {id} has failed." : "Η λήψη της σημείωσης {id} απέτυχε.",
    "Refreshing note {id} has failed." : "Η ανανέωση της σημείωσης {id} απέτυχε.",
    "Renaming note {id} has failed." : "Η μετονομασία της σημείωσης {id} απέτυχε.",
    "Creating new note has failed." : "Η δημιουργία νέας σημείωσης απέτυχε.",
    "Saving note {id} has failed." : "Η αποθήκευση της σημείωσης {id} απέτυχε.",
    "Updating title for note {id} has failed." : "Η ενημέρωση του τίτλου της σημείωσης {id} απέτυχε.",
    "Undo delete has failed for note {title}." : "Η αναίρεση διαγραφής της σημείωσης {title} απέτυχε.",
    "Deleting note {id} has failed." : "Η διαγραφή της σημείωσης {id} απέτυχε.",
    "Toggling favorite for note {id} has failed." : "Η εναλλαγή του αγαπημένου για τη σημείωση {id} απέτυχε.",
    "Updating the note's category has failed. Is the target directory writable?" : "Η ενημέρωση της κατηγορίας σημείωσης απέτυχε. Ο κατάλογος είναι εγγράψιμος;",
    "Updating the category for note {id} has failed." : "Η ενημέρωση της κατηγορίας σημείωσης {id} απέτυχε.",
    "Development Mode" : "Κατάσταση προγραμματισμού",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Φαίνεται ότι η εφαρμογή σημειώσεων εγκαταστάθηκε από μια τρίτη πηγή ανάπτυξης. Παρακαλούμε εγκαταστήστε από την επίσημη <a href=\"%1$s\"> Αγορά Εφαρμογών Nextcloud</a>. Αν επιθυμείτε να αναπτύξετε την εφαρμογή Σημειώσεων, παρακαλούμε ακολουθήστε τις <a href=\"%2$s\">οδηγίες προγραμματιστών</a>."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-notes-3.6.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/notes/l10n/el.js <==
OC.L10N.register(
    "notes",
    {
    "Reading notes from filesystem has failed." : "Η ανάγνωση από το αρχείο συστήματος απέτυχε.",
    "Error" : "Σφάλμα",
    "New note" : "Νέα σημείωση",
    "Notes" : "Σημειώσεις",
    "Distraction-free notes and writing" : "Χωρίς περιορισμούς σημειώσεις και γραφή",
    "Please see Nextcloud server log for details." : "Για λεπτομέρειες παρακαλούμε δείτε το ιστορικό του διακομιστή Nextcloud.",
    "Deleted {title}" : "Διεγραμμένες {title}",
    "Deleted {number} notes" : "Διαγράφηκαν {number} σημειώσεις",
    "Undo Delete" : "Αναίρεση διαγραφής",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Υπάρχουν σημειώσεις που δεν έχουν αποθηκευτεί. Φεύγοντας από την σελίδα θα διαγραφούν οι αλλαγές!",
    "Settings" : "Ρυθμίσεις",
    "Folder to store your notes" : "Φάκελος αποθήκευσης των σημειώσεών σας",
    "path to notes" : "διαδρομή στις σημειώσεις",
    "File extension for new notes" : "Πρόσθετο αρχείου για νέες σημειώσεις",
    "All notes" : "Όλες οι σημειώσεις",
    "Categories" : "Κατηγορίες",
    "No search result for “{search}” in {category}" : "Κανένα αποτέλεσμα αναζήτησης για “{search}” σε {category}",
    "No search result for “{search}”" : "Κανένα αποτέλεσμα αναζήτησης για “{search}”",
    "Loading …" : "Φόρτωση…",
    "Search result for “{search}” in {category}" : "Αποτέλεσμα αναζήτησης για “{search}” σε {category}",
    "Search result for “{search}”" : "Αποτέλεσμα αναζήτησης για “{search}”",
    "Today" : "Σήμερα",
    "Yesterday" : "Χθές",
    "This week" : "Αυτή την εβδομάδα",
    "Last week" : "Προηγούμενη εβδομάδα",
    "This month" : "Αυτό το μήνα",
    "Last month" : "Προηγούμενος μήνας",
    "Rename" : "Μετονομασία",
    "Note's title" : "Τίτλος σημειωματάριου",
    "Delete note" : "Διαγραφή σημείωσης",
    "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
    "Add to favorites" : "Προσθήκη στα αγαπημένα ",
    "Error during preparing note for deletion." : "Σφάλμα κατά την προετοιμασία της σημείωσης για διαγραφή.",
    "Empty note" : "Κενή σημείωση",
    "Write …" : "Σύνταξη ...",
    "Details" : "Λεπτομέρειες",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Επεξεργασία",
    "Preview" : "Προεπισκόπηση",
    "Exit full screen" : "Έξοδος πλήρους οθόνης",
    "Full screen" : "Πλήρης οθόνη",
    "Save failed. Click to retry." : "Η αποθήκευση απέτυχε. Κλίκ για προσπάθεια ξανά.",
    "Set category" : "Ορίστε κατηγορία",
    "Category" : "Κατηγορία",
    "Uncategorized" : "Χωρίς κατηγορία",
    "Click here to save manually" : "Κλίκ εδώ για χειροκίνητη αποθήκευση",
    "Saving failed!" : "Απέτυχε η αποθήκευση!",
    "Last modified: {date}" : "Τελευταία τροποίηση: {date}",
    "Note has unsaved changes" : "Η σημείωση έχει αλλαγές που δεν έχουν αποθηκευτεί",
    "Subcategory" : "Υποκατηγορία",
    "_%n word_::_%n words_" : ["%n λέξη","%n λέξεις"],
    "_%n character_::_%n characters_" : ["%n χαρακτήρας","%n χαρακτήρες"],
    "Write down your thoughts without any distractions." : "Κρατήστε τις σκέψεις σας χωρίς περιορισμούς.",
    "Use Markdown markups to style your text." : "Με χρήση του Markdown για να δώσετε στυλ στο κείμενό σας.",
    "Organize your notes in categories." : "Οργανώστε τις σημειώσεις σας σε κατηγορίες.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Εγκαταστήστε την εφαρμογή στο κινητό σας για πρόσβαση από οπουδήποτε.",
    "Android app" : "Εφαρμογή Android",
    "iOS app" : "Εφαρμογή iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Ξεκινήστε μια σημείωση κάνοντας κλικ στο \"{newnote}\" από το μενού εφαρμογών.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Μπορείτε να δημιουργήσετε υποκατηγορίες χρησιμοποιώντας το \"/\" ως οριοθέτη μεταξύ της κατηγορίας και της υποκατηγορίας, π.χ. \"{Parent}/{sub}\".",
    "Note not found." : "Δεν βρέθηκε η σημείωση.",
    "Note is locked." : "Η σημείωση είναι κλειδωμένη.",
    "Insufficient storage." : "Μη επαρκής αποθηκευτικός χώρος.",
    "See JavaScript console and server log for details." : "Δείτε την κονσόλα JavaScript και το ιστορικό του διακομιστή για λεπτομέρειες.",
    "Updating settings has failed." : "Η ενημέρωση ρυθμίσεων απέτυχε.",
    "Error from Nextcloud server: {msg}" : "Σφάλμα από τον διακομιστή Nextcloud: {msg}",
    "Fetching notes has failed." : "Η λήψη σημειώσεων απέτυχε.",
    "Fetching note {id} has failed." : "Η λήψη της σημείωσης {id} απέτυχε.",
    "Refreshing note {id} has failed." : "Η ανανέωση της σημείωσης {id} απέτυχε.",
    "Renaming note {id} has failed." : "Η μετονομασία της σημείωσης {id} απέτυχε.",
    "Creating new note has failed." : "Η δημιουργία νέας σημείωσης απέτυχε.",
    "Saving note {id} has failed." : "Η αποθήκευση της σημείωσης {id} απέτυχε.",
    "Updating title for note {id} has failed." : "Η ενημέρωση του τίτλου της σημείωσης {id} απέτυχε.",
    "Undo delete has failed for note {title}." : "Η αναίρεση διαγραφής της σημείωσης {title} απέτυχε.",
    "Deleting note {id} has failed." : "Η διαγραφή της σημείωσης {id} απέτυχε.",
    "Toggling favorite for note {id} has failed." : "Η εναλλαγή του αγαπημένου για τη σημείωση {id} απέτυχε.",
    "Updating the note's category has failed. Is the target directory writable?" : "Η ενημέρωση της κατηγορίας σημείωσης απέτυχε. Ο κατάλογος είναι εγγράψιμος;",
    "Updating the category for note {id} has failed." : "Η ενημέρωση της κατηγορίας σημείωσης {id} απέτυχε.",
    "Development Mode" : "Κατάσταση προγραμματισμού",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Φαίνεται ότι η εφαρμογή σημειώσεων εγκαταστάθηκε από μια τρίτη πηγή ανάπτυξης. Παρακαλούμε εγκαταστήστε από την επίσημη <a href=\"%1$s\"> Αγορά Εφαρμογών Nextcloud</a>. Αν επιθυμείτε να αναπτύξετε την εφαρμογή Σημειώσεων, παρακαλούμε ακολουθήστε τις <a href=\"%2$s\">οδηγίες προγραμματιστών</a>."
},
"nplurals=2; plural=(n != 1);");
